#include <avr/io.h>
#include <avr/interrupt.h>


#define MainPowerOff()\
	PORTB |= 0x40\

#define MainPowerOn()\
	PORTB &=~ 0x40\


#define ChargeOff()\
	PORTD &=~ 0x20\

#define ChargeOn()\
	PORTD |= 0x20\


#define LedOff()\
	PORTB &=~ 0x01\

#define LedOn()\
	PORTB |= 0x01\





static void port_init(void)
{
 PORTB = 0x80;
 DDRB  = 0x7F;
 
 PORTC = 0x7F;
 DDRC  = 0x00;

 PORTD = 0x5F;
 DDRD  = 0xA0;
}


//TIMER1 initialize - prescale:1024 WGM: 0) Normal, TOP=0xFFFF 
// desired value: 1Sec, actual value:  0,999Sec (0,1%)
static void timer1_init(void)
{
 
 TCCR1B = 0x00; //stop
 TCNT1H = 0xFC;
 TCNT1L = 0x30;
 TCCR1A = 0x00;
 TCCR1B = 0x05; //start Timer
// TIMSK1 = 0x01;		// for mega48
}


//ADC initialize. Conversion time: 208uS (div 16)
static void adc_init(void)
{
 ADCSR = 0x00; //disable adc
 ADMUX = 0x00; //select adc input 0
 ACSR  = 0x80;
 ADCSR = 0x8C;
}


//TIMER1 has overflowed
ISR(TIMER1_OVF_vect)
{
 TCNT1H = 0xFC; //reload counter high value
 TCNT1L = 0x30; //reload counter low value
 
 PORTB ^= 0x08;
}


//     
ISR(ADC_vect)
{
 //conversion complete, read value (int) using...
 // value=ADCL;            //Read 8 low bits first (important)
 // value|=(int)ADCH << 8; //read 2 high bits and shift into top byte
}


//      
ISR(INT0_vect, ISR_NAKED)
{
 MainPowerOff();
 reti();
}


//        
ISR(INT1_vect, ISR_NAKED)
{
 ChargeOff();
 reti();
}


//call this routine to initialize all peripherals
static void init_devices(void)
{
 cli(); 		//disable all interrupts

 port_init();
 timer1_init();
 adc_init();

 MCUCR = 0x0A;
 GICR  = 0xC0;
 TIMSK = 0x04; //timer interrupt sources

 sei(); 		//re-enable interrupts
}


int main(void)
{
 
 init_devices();

 do
 {
 }while(1);
}
